summaryrefslogtreecommitdiff
path: root/MdeModulePkg/Core
diff options
context:
space:
mode:
authoreric_tian <eric_tian@6f19259b-4bc3-4df7-8a09-765794883524>2009-04-08 08:14:09 +0000
committereric_tian <eric_tian@6f19259b-4bc3-4df7-8a09-765794883524>2009-04-08 08:14:09 +0000
commit3d4d0c34f9011e273987dad8b12b6753d495afb9 (patch)
tree4faf7205a07e2b74bbdbc402bd79318528aaae02 /MdeModulePkg/Core
parent63d55bb98a5fa3018378d06c50784e463c6e999a (diff)
downloadedk2-3d4d0c34f9011e273987dad8b12b6753d495afb9.zip
edk2-3d4d0c34f9011e273987dad8b12b6753d495afb9.tar.gz
edk2-3d4d0c34f9011e273987dad8b12b6753d495afb9.tar.bz2
updated to use the term “temporary memory” but not CAR
git-svn-id: https://edk2.svn.sourceforge.net/svnroot/edk2/trunk/edk2@8035 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'MdeModulePkg/Core')
-rw-r--r--MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c14
-rw-r--r--MdeModulePkg/Core/Pei/Memory/MemoryServices.c4
-rw-r--r--MdeModulePkg/Core/Pei/PeiMain.h4
-rw-r--r--MdeModulePkg/Core/Pei/Ppi/Ppi.c2
4 files changed, 12 insertions, 12 deletions
diff --git a/MdeModulePkg/Core/Pei/Memory/MemoryServices.c b/MdeModulePkg/Core/Pei/Memory/MemoryServices.c
index 02e83a1..6314f75 100644
--- a/MdeModulePkg/Core/Pei/Memory/MemoryServices.c
+++ b/MdeModulePkg/Core/Pei/Memory/MemoryServices.c
@@ -149,7 +149,7 @@ PeiAllocatePages (
//
if (!PrivateData->PeiMemoryInstalled) {
//
- // When PeiInstallMemory is called but CAR has *not* been moved to temporary memory,
+ // When PeiInstallMemory is called but temporary memory has *not* been moved to temporary memory,
// the AllocatePage will depend on the field of PEI_CORE_INSTANCE structure.
//
if (!PrivateData->SwitchStackSignal) {
@@ -207,7 +207,7 @@ PeiAllocatePages (
/**
Pool allocation service. Before permenent memory is discoveried, the pool will
- be allocated the heap in the CAR. Genenrally, the size of heap in temporary
+ be allocated the heap in the temporary memory. Genenrally, the size of heap in temporary
memory does not exceed to 64K, so the biggest pool size could be allocated is
64K.
diff --git a/MdeModulePkg/Core/Pei/PeiMain.h b/MdeModulePkg/Core/Pei/PeiMain.h
index 453f230..1d96cc4 100644
--- a/MdeModulePkg/Core/Pei/PeiMain.h
+++ b/MdeModulePkg/Core/Pei/PeiMain.h
@@ -333,7 +333,7 @@ InitializePpiServices (
/**
- Migrate the Hob list from the CAR stack to PEI installed memory.
+ Migrate the Hob list from the temporary memory stack to PEI installed memory.
@param PrivateData Pointer to PeiCore's private data structure.
@param OldCheckingBottom Bottom of temporary memory range. All Ppi in this range
@@ -765,7 +765,7 @@ PeiAllocatePages (
/**
- Memory allocation service on the CAR.
+ Memory allocation service on the temporary memory.
@param PeiServices An indirect pointer to the EFI_PEI_SERVICES table published by the PEI Foundation.
diff --git a/MdeModulePkg/Core/Pei/Ppi/Ppi.c b/MdeModulePkg/Core/Pei/Ppi/Ppi.c
index ffed6cf..04b29ec 100644
--- a/MdeModulePkg/Core/Pei/Ppi/Ppi.c
+++ b/MdeModulePkg/Core/Pei/Ppi/Ppi.c
@@ -38,7 +38,7 @@ InitializePpiServices (
/**
- Migrate the Hob list from the CAR stack to PEI installed memory.
+ Migrate the Hob list from the temporary memory stack to PEI installed memory.
@param PrivateData Pointer to PeiCore's private data structure.
@param OldCheckingBottom Bottom of temporary memory range. All Ppi in this range
diff --git a/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c b/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c
index 9caa890..f64003d 100644
--- a/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c
+++ b/MdeModulePkg/Core/Pei/Dispatcher/Dispatcher.c
@@ -15,7 +15,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
#include "PeiMain.h"
///
/// CAR is filled with this initial value during SEC phase
///
#define INIT_CAR_VALUE 0x5AA55AA5
@@ -442,7 +442,7 @@ PeiDispatcher (
if (Private->SwitchStackSignal) {
//
- // Before switch stack from CAR to permenent memory, caculate the heap and stack
+ // Before switch stack from temporary memory to permenent memory, caculate the heap and stack
// usage in temporary memory for debuging.
//
DEBUG_CODE_BEGIN ();
@@ -453,11 +453,11 @@ PeiDispatcher (
&& (*StackPointer == INIT_CAR_VALUE);
StackPointer ++);
- DEBUG ((EFI_D_INFO, "Total Cache as RAM: %d bytes.\n", (UINT32)SecCoreData->TemporaryRamSize));
- DEBUG ((EFI_D_INFO, " CAR stack ever used: %d bytes.\n",
+ DEBUG ((EFI_D_INFO, "Total temporary memory: %d bytes.\n", (UINT32)SecCoreData->TemporaryRamSize));
+ DEBUG ((EFI_D_INFO, " temporary memory stack ever used: %d bytes.\n",
(SecCoreData->StackSize - ((UINTN) StackPointer - (UINTN)SecCoreData->StackBase))
));
- DEBUG ((EFI_D_INFO, " CAR heap used: %d bytes.\n",
+ DEBUG ((EFI_D_INFO, " temporary memory heap used: %d bytes.\n",
((UINTN) Private->HobList.HandoffInformationTable->EfiFreeMemoryBottom -
(UINTN) Private->HobList.Raw)
));
@@ -498,7 +498,7 @@ PeiDispatcher (
NewPermenentMemoryBase = Private->PhysicalMemoryBegin + StackGap;
//
// Caculate stack offset and heap offset between CAR and new permement
// memory seperately.
//
StackOffset = (UINTN) NewPermenentMemoryBase - (UINTN) SecCoreData->StackBase;
@@ -529,7 +529,7 @@ PeiDispatcher (
// Temporary Ram support Ppi is provided by platform, it will copy
// temporary memory to permenent memory and do stack switching.
// After invoken temporary Ram support, following code's stack is in
- // memory but not in CAR.
+ // memory but not in temporary memory.
//
TemporaryRamSupportPpi->TemporaryRamMigration (
(CONST EFI_PEI_SERVICES **) PeiServices,
@@ -15,7 +15,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
#include "PeiMain.h"
///
-/// CAR is filled with this initial value during SEC phase
+/// temporary memory is filled with this initial value during SEC phase
///
#define INIT_CAR_VALUE 0x5AA55AA5
@@ -498,7 +498,7 @@ PeiDispatcher (
NewPermenentMemoryBase = Private->PhysicalMemoryBegin + StackGap;
//
- // Caculate stack offset and heap offset between CAR and new permement
+ // Caculate stack offset and heap offset between temporary memory and new permement
// memory seperately.
//